﻿using Infragistics;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Windows;
using System.Windows.Controls;

namespace SilverlightApplication18
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            this.Loaded += MainPage_Loaded;
        }

        private void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            this.xamGrid.ItemsSource = Enumerable.Range(0, 100000).Select(item => new DataItem(item));
            this.xamGrid.Columns.DataColumns["Id"].SummaryColumnSettings.SummaryOperands.Add(new DummyOperand());
        }
    }

    public class DataItem
    {
        public DataItem()
        {

        }

        public DataItem(int id)
        {
            this.Id = id;
            this.Name = "Item " + id;
        }
        public int Id { get; set; }
        public string Name { get; set; }
    }

    public class DummyCalc : SynchronousSummaryCalculator
    {
        public double Count { get; set; }
        public List<DataItem> Data { get; set; }

        public override SummaryExecution? SummaryExecution
        {
            get
            {
                // Default xamGrid SummaryExecution value
                return Infragistics.SummaryExecution.PriorToFilteringAndPaging;
            }
        }

        public override object Summarize(IQueryable data, string fieldKey)
        {
            //Dispatcher dispatcher = Deployment.Current.Dispatcher;
            
            Data = data.Cast<DataItem>().ToList();

            return new ChartData(Data);
        }
    }

    public class DummyOperand : SummaryOperandBase
    {
        DummyCalc myCalc;

        protected override string DefaultRowDisplayLabel
        {
            get { return "Custom Summary"; }
        }

        protected override string DefaultSelectionDisplayLabel
        {
            get { return "Custom Summary"; }
        }

        public override SummaryCalculatorBase SummaryCalculator
        {
            get
            {
                if (myCalc == null)
                {
                    this.myCalc = new DummyCalc();
                }

                return this.myCalc;
            }
        }
    }

    public class ChartData : INotifyPropertyChanged
    {

        public List<DataItem> Data { get; set; }

        public ChartData(List<DataItem> items )
        {
            Data = items;
            var worker = new BackgroundWorker { WorkerReportsProgress = true, WorkerSupportsCancellation = true };
            worker.DoWork += new DoWorkEventHandler(worker_DoWork);
            worker.RunWorkerCompleted += new RunWorkerCompletedEventHandler(worker_RunWorkerCompleted);
            worker.RunWorkerAsync();
        }

        private void worker_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
        {
            
            AvarageResult = (int)e.Result;
        }

        private void worker_DoWork(object sender, DoWorkEventArgs e)
        {
            e.Result = Data.Count;
        }

        private int _AvarageResult;
        public int AvarageResult
        {
            get
            {
                return _AvarageResult;
            }
            set
            {
                _AvarageResult = value;
                OnPropertyChanged(new PropertyChangedEventArgs("AvarageResult"));
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropertyChanged(PropertyChangedEventArgs e)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, e);
            }
        }
    }


    
}
